==> haskell-warp-quic-0.0.0-400-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-warp-quic.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 warp-quic
version:              0.0.0
visibility:           public
id:                   warp-quic-0.0.0-2Z2AujGdhYm5ZFbKx2Z8mN
key:                  warp-quic-0.0.0-2Z2AujGdhYm5ZFbKx2Z8mN
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             https://github.com/kazu-yamamoto/warp-quic
synopsis:             Warp based on QUIC
description:          WAI handler for HTTP/3 based on QUIC
category:             Network
abi:                  8fd7147f590e5872424db4a3166143a0
exposed:              True
exposed-modules:      Network.Wai.Handler.WarpQUIC
import-dirs:          /usr/lib/ghc-9.4.8/site-local/warp-quic-0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/warp-quic-0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/warp-quic-0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-warp-quic
hs-libraries:         HSwarp-quic-0.0.0-2Z2AujGdhYm5ZFbKx2Z8mN
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    http3-0.0.7-Ck5XAtdeIR8CexyTzrIuKH
    quic-0.1.22-DtpkE82EuZe5VIhG9vvIaE tls-2.0.6-C4tG7nFxAIj3KL8r1HO92U
    wai-3.2.4-7gPy4vrA6McEXoAULdTry7 warp-3.3.31-BWp9L2zAoW4JruynxSXs04

haddock-interfaces:   /usr/share/doc/haskell-warp-quic/html/warp-quic.haddock
haddock-html:         /usr/share/doc/haskell-warp-quic/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-warp-quic-0.0.0-401-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-warp-quic.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 warp-quic
version:              0.0.0
visibility:           public
id:                   warp-quic-0.0.0-6Zf3B6BjPr48T5SMjrFvNk
key:                  warp-quic-0.0.0-6Zf3B6BjPr48T5SMjrFvNk
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             https://github.com/kazu-yamamoto/warp-quic
synopsis:             Warp based on QUIC
description:          WAI handler for HTTP/3 based on QUIC
category:             Network
abi:                  15c43ee557e73831bdb1580863c41a56
exposed:              True
exposed-modules:      Network.Wai.Handler.WarpQUIC
import-dirs:          /usr/lib/ghc-9.4.8/site-local/warp-quic-0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/warp-quic-0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/warp-quic-0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-warp-quic
hs-libraries:         HSwarp-quic-0.0.0-6Zf3B6BjPr48T5SMjrFvNk
depends:
    base-4.17.2.1 bytestring-0.11.5.3 http3-0.0.7-K8FPee3j30WG1gwkGDsTg
    quic-0.1.22-2ZftOHFmTBI8Hjk9G4zR12 tls-2.0.6-254SZCnYbBgCVlh9irR6QI
    wai-3.2.4-F2VJAE8OhtyI4jBCcdCBBc warp-3.3.31-7Ui8U5N0UghGK11l5Hbjef

haddock-interfaces:   /usr/share/doc/haskell-warp-quic/html/warp-quic.haddock
haddock-html:         /usr/share/doc/haskell-warp-quic/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
